Title: [143264] trunk/Source/WebCore
Revision
143264
Author
[email protected]
Date
2013-02-18 14:31:54 -0800 (Mon, 18 Feb 2013)

Log Message

Introduced AbstractSQLStatement and AbstractSQLStatementBackend.
https://bugs.webkit.org/show_bug.cgi?id=110148.

Reviewed by Geoff Garen.

This is part of the webdatabase refactoring for webkit2.
- Also changed the frontend and backend to only refer to the
  abstract interface of each other.

No new tests.

* GNUmakefile.list.am:
* Modules/webdatabase/AbstractSQLStatement.h: Added.
(AbstractSQLStatement):
(WebCore::AbstractSQLStatement::~AbstractSQLStatement):
* Modules/webdatabase/AbstractSQLStatementBackend.h: Added.
(AbstractSQLStatementBackend):
(WebCore::AbstractSQLStatementBackend::~AbstractSQLStatementBackend):
* Modules/webdatabase/SQLStatement.cpp:
(WebCore::SQLStatement::setBackend):
* Modules/webdatabase/SQLStatement.h:
(SQLStatement):
* Modules/webdatabase/SQLStatementBackend.cpp:
(WebCore::SQLStatementBackend::create):
(WebCore::SQLStatementBackend::SQLStatementBackend):
(WebCore::SQLStatementBackend::frontend):
* Modules/webdatabase/SQLStatementBackend.h:
(SQLStatementBackend):
* Modules/webdatabase/SQLTransaction.cpp:
(WebCore::SQLTransaction::deliverStatementCallback):
* Modules/webdatabase/SQLTransactionBackend.cpp:
(WebCore::SQLTransactionBackend::currentStatement):
(WebCore::SQLTransactionBackend::executeSQL):
* Modules/webdatabase/SQLTransactionBackend.h:
(SQLTransactionBackend):
* Target.pri:
* WebCore.gypi:
* WebCore.vcproj/WebCore.vcproj:
* WebCore.vcxproj/WebCore.vcxproj:
* WebCore.vcxproj/WebCore.vcxproj.filters:
* WebCore.xcodeproj/project.pbxproj:

Modified Paths

Added Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (143263 => 143264)


--- trunk/Source/WebCore/ChangeLog	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/ChangeLog	2013-02-18 22:31:54 UTC (rev 143264)
@@ -1,3 +1,47 @@
+2013-02-18  Mark Lam  <[email protected]>
+
+        Introduced AbstractSQLStatement and AbstractSQLStatementBackend.
+        https://bugs.webkit.org/show_bug.cgi?id=110148.
+
+        Reviewed by Geoff Garen.
+
+        This is part of the webdatabase refactoring for webkit2.
+        - Also changed the frontend and backend to only refer to the
+          abstract interface of each other.
+
+        No new tests.
+
+        * GNUmakefile.list.am:
+        * Modules/webdatabase/AbstractSQLStatement.h: Added.
+        (AbstractSQLStatement):
+        (WebCore::AbstractSQLStatement::~AbstractSQLStatement):
+        * Modules/webdatabase/AbstractSQLStatementBackend.h: Added.
+        (AbstractSQLStatementBackend):
+        (WebCore::AbstractSQLStatementBackend::~AbstractSQLStatementBackend):
+        * Modules/webdatabase/SQLStatement.cpp:
+        (WebCore::SQLStatement::setBackend):
+        * Modules/webdatabase/SQLStatement.h:
+        (SQLStatement):
+        * Modules/webdatabase/SQLStatementBackend.cpp:
+        (WebCore::SQLStatementBackend::create):
+        (WebCore::SQLStatementBackend::SQLStatementBackend):
+        (WebCore::SQLStatementBackend::frontend):
+        * Modules/webdatabase/SQLStatementBackend.h:
+        (SQLStatementBackend):
+        * Modules/webdatabase/SQLTransaction.cpp:
+        (WebCore::SQLTransaction::deliverStatementCallback):
+        * Modules/webdatabase/SQLTransactionBackend.cpp:
+        (WebCore::SQLTransactionBackend::currentStatement):
+        (WebCore::SQLTransactionBackend::executeSQL):
+        * Modules/webdatabase/SQLTransactionBackend.h:
+        (SQLTransactionBackend):
+        * Target.pri:
+        * WebCore.gypi:
+        * WebCore.vcproj/WebCore.vcproj:
+        * WebCore.vcxproj/WebCore.vcxproj:
+        * WebCore.vcxproj/WebCore.vcxproj.filters:
+        * WebCore.xcodeproj/project.pbxproj:
+
 2013-02-18  David Kilzer  <[email protected]>
 
         BUILD FIX (r143230): Fix renamed header and implementation of -[WebAccessibilityObjectWrapper accessibilityPostedNotification:]

Modified: trunk/Source/WebCore/GNUmakefile.list.am (143263 => 143264)


--- trunk/Source/WebCore/GNUmakefile.list.am	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/GNUmakefile.list.am	2013-02-18 22:31:54 UTC (rev 143264)
@@ -2100,6 +2100,8 @@
 	Source/WebCore/Modules/webaudio/WaveTable.cpp \
 	Source/WebCore/Modules/webaudio/WaveTable.h \
 	Source/WebCore/Modules/webdatabase/AbstractDatabaseServer.h \
+	Source/WebCore/Modules/webdatabase/AbstractSQLStatement.h \
+	Source/WebCore/Modules/webdatabase/AbstractSQLStatementBackend.h \
 	Source/WebCore/Modules/webdatabase/ChangeVersionData.h \
 	Source/WebCore/Modules/webdatabase/ChangeVersionWrapper.cpp \
 	Source/WebCore/Modules/webdatabase/ChangeVersionWrapper.h \

Added: trunk/Source/WebCore/Modules/webdatabase/AbstractSQLStatement.h (0 => 143264)


--- trunk/Source/WebCore/Modules/webdatabase/AbstractSQLStatement.h	                        (rev 0)
+++ trunk/Source/WebCore/Modules/webdatabase/AbstractSQLStatement.h	2013-02-18 22:31:54 UTC (rev 143264)
@@ -0,0 +1,51 @@
+/*
+ * Copyright (C) 2013 Apple Inc. All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
+ */
+
+#ifndef AbstractSQLStatement_h
+#define AbstractSQLStatement_h
+
+#if ENABLE(SQL_DATABASE)
+
+#include <wtf/ThreadSafeRefCounted.h>
+
+namespace WebCore {
+
+class AbstractSQLStatementBackend;
+
+class AbstractSQLStatement {
+public:
+    virtual ~AbstractSQLStatement() { }
+
+    virtual void setBackend(AbstractSQLStatementBackend*) = 0;
+
+    virtual bool hasCallback() = 0;
+    virtual bool hasErrorCallback() = 0;
+};
+
+} // namespace WebCore
+
+#endif // ENABLE(SQL_DATABASE)
+
+#endif // AbstractSQLStatement_h

Added: trunk/Source/WebCore/Modules/webdatabase/AbstractSQLStatementBackend.h (0 => 143264)


--- trunk/Source/WebCore/Modules/webdatabase/AbstractSQLStatementBackend.h	                        (rev 0)
+++ trunk/Source/WebCore/Modules/webdatabase/AbstractSQLStatementBackend.h	2013-02-18 22:31:54 UTC (rev 143264)
@@ -0,0 +1,49 @@
+/*
+ * Copyright (C) 2013 Apple Inc. All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *    notice, this list of conditions and the following disclaimer in the
+ *    documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
+ * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
+ * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
+ * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. 
+ */
+
+#ifndef AbstractSQLStatementBackend_h
+#define AbstractSQLStatementBackend_h
+
+#if ENABLE(SQL_DATABASE)
+
+#include "SQLError.h"
+#include "SQLResultSet.h"
+#include <wtf/ThreadSafeRefCounted.h>
+
+namespace WebCore {
+
+class AbstractSQLStatementBackend : public ThreadSafeRefCounted<AbstractSQLStatementBackend> {
+public:
+    virtual ~AbstractSQLStatementBackend() { }
+
+    virtual PassRefPtr<SQLError> sqlError() const = 0;
+    virtual PassRefPtr<SQLResultSet> sqlResultSet() const = 0;
+};
+
+} // namespace WebCore
+
+#endif // ENABLE(SQL_DATABASE)
+
+#endif // AbstractSQLStatementBackend_h

Modified: trunk/Source/WebCore/Modules/webdatabase/SQLStatement.cpp (143263 => 143264)


--- trunk/Source/WebCore/Modules/webdatabase/SQLStatement.cpp	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/Modules/webdatabase/SQLStatement.cpp	2013-02-18 22:31:54 UTC (rev 143264)
@@ -31,11 +31,10 @@
 #if ENABLE(SQL_DATABASE)
 
 #include "AbstractDatabaseServer.h"
+#include "AbstractSQLStatementBackend.h"
 #include "Database.h"
 #include "DatabaseManager.h"
 #include "Logging.h"
-#include "SQLError.h"
-#include "SQLStatementBackend.h"
 #include "SQLStatementCallback.h"
 #include "SQLStatementErrorCallback.h"
 #include "SQLTransaction.h"
@@ -59,7 +58,7 @@
 {
 }
 
-void SQLStatement::setBackend(SQLStatementBackend* backend)
+void SQLStatement::setBackend(AbstractSQLStatementBackend* backend)
 {
     m_backend = backend;
 }

Modified: trunk/Source/WebCore/Modules/webdatabase/SQLStatement.h (143263 => 143264)


--- trunk/Source/WebCore/Modules/webdatabase/SQLStatementBackend.cpp	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/Modules/webdatabase/SQLStatementBackend.cpp	2013-02-18 22:31:54 UTC (rev 143264)
@@ -30,12 +30,10 @@
 
 #if ENABLE(SQL_DATABASE)
 
+#include "AbstractSQLStatement.h"
 #include "DatabaseBackendAsync.h"
 #include "Logging.h"
 #include "SQLError.h"
-#include "SQLStatement.h"
-#include "SQLStatementCallback.h"
-#include "SQLStatementErrorCallback.h"
 #include "SQLValue.h"
 #include "SQLiteDatabase.h"
 #include "SQLiteStatement.h"
@@ -76,13 +74,13 @@
 
 namespace WebCore {
 
-PassRefPtr<SQLStatementBackend> SQLStatementBackend::create(PassOwnPtr<SQLStatement> frontend,
+PassRefPtr<SQLStatementBackend> SQLStatementBackend::create(PassOwnPtr<AbstractSQLStatement> frontend,
     const String& statement, const Vector<SQLValue>& arguments, int permissions)
 {
     return adoptRef(new SQLStatementBackend(frontend, statement, arguments, permissions));
 }
 
-SQLStatementBackend::SQLStatementBackend(PassOwnPtr<SQLStatement> frontend,
+SQLStatementBackend::SQLStatementBackend(PassOwnPtr<AbstractSQLStatement> frontend,
     const String& statement, const Vector<SQLValue>& arguments, int permissions)
     : m_frontend(frontend)
     , m_statement(statement.isolatedCopy())
@@ -94,7 +92,7 @@
     m_frontend->setBackend(this);
 }
 
-SQLStatement* SQLStatementBackend::frontend()
+AbstractSQLStatement* SQLStatementBackend::frontend()
 {
     return m_frontend.get();
 }

Modified: trunk/Source/WebCore/Modules/webdatabase/SQLStatementBackend.h (143263 => 143264)


--- trunk/Source/WebCore/Modules/webdatabase/SQLStatementBackend.h	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/Modules/webdatabase/SQLStatementBackend.h	2013-02-18 22:31:54 UTC (rev 143264)
@@ -30,22 +30,23 @@
 
 #if ENABLE(SQL_DATABASE)
 
-#include "SQLResultSet.h"
+#include "AbstractSQLStatementBackend.h"
 #include "SQLValue.h"
 #include <wtf/Forward.h>
+#include <wtf/PassOwnPtr.h>
 #include <wtf/Vector.h>
 #include <wtf/text/WTFString.h>
 
 namespace WebCore {
 
+class AbstractSQLStatement;
 class DatabaseBackendAsync;
 class SQLError;
-class SQLStatement;
 class SQLTransactionBackend;
 
-class SQLStatementBackend : public ThreadSafeRefCounted<SQLStatementBackend> {
+class SQLStatementBackend : public AbstractSQLStatementBackend {
 public:
-    static PassRefPtr<SQLStatementBackend> create(PassOwnPtr<SQLStatement>,
+    static PassRefPtr<SQLStatementBackend> create(PassOwnPtr<AbstractSQLStatement>,
         const String& sqlStatement, const Vector<SQLValue>& arguments, int permissions);
 
     bool execute(DatabaseBackendAsync*);
@@ -57,18 +58,18 @@
     void setDatabaseDeletedError(DatabaseBackendAsync*);
     void setVersionMismatchedError(DatabaseBackendAsync*);
 
-    SQLStatement* frontend();
-    PassRefPtr<SQLError> sqlError() const;
-    PassRefPtr<SQLResultSet> sqlResultSet() const;
+    AbstractSQLStatement* frontend();
+    virtual PassRefPtr<SQLError> sqlError() const;
+    virtual PassRefPtr<SQLResultSet> sqlResultSet() const;
 
 private:
-    SQLStatementBackend(PassOwnPtr<SQLStatement>, const String& statement,
+    SQLStatementBackend(PassOwnPtr<AbstractSQLStatement>, const String& statement,
         const Vector<SQLValue>& arguments, int permissions);
 
     void setFailureDueToQuota(DatabaseBackendAsync*);
     void clearFailureDueToQuota();
 
-    OwnPtr<SQLStatement> m_frontend;
+    OwnPtr<AbstractSQLStatement> m_frontend;
     String m_statement;
     Vector<SQLValue> m_arguments;
     bool m_hasCallback;

Modified: trunk/Source/WebCore/Modules/webdatabase/SQLTransaction.cpp (143263 => 143264)


--- trunk/Source/WebCore/Modules/webdatabase/SQLTransaction.cpp	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/Modules/webdatabase/SQLTransaction.cpp	2013-02-18 22:31:54 UTC (rev 143264)
@@ -174,7 +174,8 @@
     // Otherwise, continue to loop through the statement queue
     m_executeSqlAllowed = true;
 
-    SQLStatement* currentStatement = m_backend->currentStatement();
+    AbstractSQLStatement* currentAbstractStatement = m_backend->currentStatement();
+    SQLStatement* currentStatement = static_cast<SQLStatement*>(currentAbstractStatement);
     ASSERT(currentStatement);
 
     bool result = currentStatement->performCallback(this);

Modified: trunk/Source/WebCore/Modules/webdatabase/SQLTransactionBackend.cpp (143263 => 143264)


--- trunk/Source/WebCore/Modules/webdatabase/SQLTransactionBackend.cpp	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/Modules/webdatabase/SQLTransactionBackend.cpp	2013-02-18 22:31:54 UTC (rev 143264)
@@ -39,10 +39,7 @@
 #include "ExceptionCode.h"
 #include "Logging.h"
 #include "SQLError.h"
-#include "SQLStatement.h"
 #include "SQLStatementBackend.h"
-#include "SQLStatementCallback.h" // FIXME: remove when SQLStatement has been refactored.
-#include "SQLStatementErrorCallback.h" // FIXME: remove when SQLStatement has been refactored.
 #include "SQLTransaction.h"
 #include "SQLTransactionClient.h"
 #include "SQLTransactionCoordinator.h"
@@ -377,7 +374,7 @@
     m_transactionError = 0;
 }
 
-SQLStatement* SQLTransactionBackend::currentStatement()
+AbstractSQLStatement* SQLTransactionBackend::currentStatement()
 {
     return m_currentStatementBackend->frontend();
 }
@@ -463,7 +460,7 @@
     runStateMachine();
 }
 
-void SQLTransactionBackend::executeSQL(PassOwnPtr<SQLStatement> statement,
+void SQLTransactionBackend::executeSQL(PassOwnPtr<AbstractSQLStatement> statement,
     const String& sqlStatement, const Vector<SQLValue>& arguments, int permissions)
 {
     RefPtr<SQLStatementBackend> statementBackend;

Modified: trunk/Source/WebCore/Modules/webdatabase/SQLTransactionBackend.h (143263 => 143264)


--- trunk/Source/WebCore/Modules/webdatabase/SQLTransactionBackend.h	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/Modules/webdatabase/SQLTransactionBackend.h	2013-02-18 22:31:54 UTC (rev 143264)
@@ -30,6 +30,7 @@
 
 #if ENABLE(SQL_DATABASE)
 
+#include "AbstractSQLStatement.h"
 #include "DatabaseBasicTypes.h"
 #include "SQLTransactionStateMachine.h"
 #include <wtf/Deque.h>
@@ -41,7 +42,6 @@
 class DatabaseBackendAsync;
 class SQLError;
 class SQLiteTransaction;
-class SQLStatement;
 class SQLStatementBackend;
 class SQLTransaction;
 class SQLTransactionBackend;
@@ -71,11 +71,11 @@
     void notifyDatabaseThreadIsShuttingDown();
 
     // APIs for the frontend:
-    SQLStatement* currentStatement();
+    AbstractSQLStatement* currentStatement();
     PassRefPtr<SQLError> transactionError();
     void setShouldRetryCurrentStatement(bool);
 
-    void executeSQL(PassOwnPtr<SQLStatement>, const String& statement,
+    void executeSQL(PassOwnPtr<AbstractSQLStatement>, const String& statement,
         const Vector<SQLValue>& arguments, int permissions);
 
 private:

Modified: trunk/Source/WebCore/Target.pri (143263 => 143264)


--- trunk/Source/WebCore/Target.pri	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/Target.pri	2013-02-18 22:31:54 UTC (rev 143264)
@@ -1457,6 +1457,8 @@
     Modules/proximity/DeviceProximityEvent.h \
     \
     Modules/webdatabase/AbstractDatabaseServer.h \
+    Modules/webdatabase/AbstractSQLStatement.h \
+    Modules/webdatabase/AbstractSQLStatementBackend.h \
     Modules/webdatabase/ChangeVersionData.h \
     Modules/webdatabase/ChangeVersionWrapper.h \
     Modules/webdatabase/DOMWindowWebDatabase.h \

Modified: trunk/Source/WebCore/WebCore.gypi (143263 => 143264)


--- trunk/Source/WebCore/WebCore.gypi	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/WebCore.gypi	2013-02-18 22:31:54 UTC (rev 143264)
@@ -984,6 +984,8 @@
             'Modules/webaudio/WaveTable.cpp',
             'Modules/webaudio/WaveTable.h',
             'Modules/webdatabase/AbstractDatabaseServer.h',
+            'Modules/webdatabase/AbstractSQLStatement.h',
+            'Modules/webdatabase/AbstractSQLStatementBackend.h',
             'Modules/webdatabase/ChangeVersionData.h',
             'Modules/webdatabase/ChangeVersionWrapper.cpp',
             'Modules/webdatabase/ChangeVersionWrapper.h',

Modified: trunk/Source/WebCore/WebCore.vcproj/WebCore.vcproj (143263 => 143264)


--- trunk/Source/WebCore/WebCore.vcproj/WebCore.vcproj	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/WebCore.vcproj/WebCore.vcproj	2013-02-18 22:31:54 UTC (rev 143264)
@@ -25378,6 +25378,14 @@
 					>
 				</File>
 				<File
+					RelativePath="..\Modules\webdatabase\AbstractSQLStatement.h"
+					>
+				</File>
+				<File
+					RelativePath="..\Modules\webdatabase\AbstractSQLStatementBackend.h"
+					>
+				</File>
+				<File
 					RelativePath="..\Modules\webdatabase\ChangeVersionData.h"
 					>
 				</File>

Modified: trunk/Source/WebCore/WebCore.vcxproj/WebCore.vcxproj (143263 => 143264)


--- trunk/Source/WebCore/WebCore.vcxproj/WebCore.vcxproj	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/WebCore.vcxproj/WebCore.vcxproj	2013-02-18 22:31:54 UTC (rev 143264)
@@ -6418,6 +6418,8 @@
     <ClInclude Include="..\Modules\notifications\NotificationClient.h" />
     <ClInclude Include="..\Modules\notifications\WorkerContextNotifications.h" />
     <ClInclude Include="..\Modules\webdatabase\AbstractDatabaseServer.h" />
+    <ClInclude Include="..\Modules\webdatabase\AbstractSQLStatement.h" />
+    <ClInclude Include="..\Modules\webdatabase\AbstractSQLStatementBackend.h" />
     <ClInclude Include="..\Modules\webdatabase\ChangeVersionData.h" />
     <ClInclude Include="..\Modules\webdatabase\ChangeVersionWrapper.h" />
     <ClInclude Include="..\Modules\webdatabase\Database.h" />

Modified: trunk/Source/WebCore/WebCore.vcxproj/WebCore.vcxproj.filters (143263 => 143264)


--- trunk/Source/WebCore/WebCore.vcxproj/WebCore.vcxproj.filters	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/WebCore.vcxproj/WebCore.vcxproj.filters	2013-02-18 22:31:54 UTC (rev 143264)
@@ -8484,6 +8484,12 @@
     <ClInclude Include="..\Modules\webdatabase\AbstractDatabaseServer.h">
       <Filter>Modules\webdatabase</Filter>
     </ClInclude>
+    <ClInclude Include="..\Modules\webdatabase\AbstractSQLStatement.h">
+      <Filter>Modules\webdatabase</Filter>
+    </ClInclude>
+    <ClInclude Include="..\Modules\webdatabase\AbstractSQLStatementBackend.h">
+      <Filter>Modules\webdatabase</Filter>
+    </ClInclude>
     <ClInclude Include="..\Modules\webdatabase\ChangeVersionData.h">
       <Filter>Modules\webdatabase</Filter>
     </ClInclude>

Modified: trunk/Source/WebCore/WebCore.xcodeproj/project.pbxproj (143263 => 143264)


--- trunk/Source/WebCore/WebCore.xcodeproj/project.pbxproj	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/WebCore.xcodeproj/project.pbxproj	2013-02-18 22:31:54 UTC (rev 143264)
@@ -6789,6 +6789,8 @@
 		FE36FD1816C7826500F887C1 /* SQLTransactionState.h in Headers */ = {isa = PBXBuildFile; fileRef = FE36FD1416C7826400F887C1 /* SQLTransactionState.h */; };
 		FE456F181677D74E005EDDF9 /* DatabaseManager.cpp in Sources */ = {isa = PBXBuildFile; fileRef = FE456F161677D74E005EDDF9 /* DatabaseManager.cpp */; };
 		FE456F191677D74E005EDDF9 /* DatabaseManager.h in Headers */ = {isa = PBXBuildFile; fileRef = FE456F171677D74E005EDDF9 /* DatabaseManager.h */; settings = {ATTRIBUTES = (Private, ); }; };
+		FE4AADEE16D2C37400026FFC /* AbstractSQLStatement.h in Headers */ = {isa = PBXBuildFile; fileRef = FE4AADEC16D2C37400026FFC /* AbstractSQLStatement.h */; settings = {ATTRIBUTES = (Private, ); }; };
+		FE4AADEF16D2C37400026FFC /* AbstractSQLStatementBackend.h in Headers */ = {isa = PBXBuildFile; fileRef = FE4AADED16D2C37400026FFC /* AbstractSQLStatementBackend.h */; settings = {ATTRIBUTES = (Private, ); }; };
 		FE6F6AAF169E057500FC30A2 /* DatabaseBackendContext.cpp in Sources */ = {isa = PBXBuildFile; fileRef = FE6F6AAD169E057500FC30A2 /* DatabaseBackendContext.cpp */; };
 		FE6F6AB0169E057500FC30A2 /* DatabaseBackendContext.h in Headers */ = {isa = PBXBuildFile; fileRef = FE6F6AAE169E057500FC30A2 /* DatabaseBackendContext.h */; settings = {ATTRIBUTES = (Private, ); }; };
 		FE6FD4880F676E5700092873 /* Coordinates.h in Headers */ = {isa = PBXBuildFile; fileRef = FE6FD4850F676E5700092873 /* Coordinates.h */; settings = {ATTRIBUTES = (Private, ); }; };
@@ -14542,6 +14544,8 @@
 		FE36FD1416C7826400F887C1 /* SQLTransactionState.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = SQLTransactionState.h; path = Modules/webdatabase/SQLTransactionState.h; sourceTree = "<group>"; };
 		FE456F161677D74E005EDDF9 /* DatabaseManager.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = DatabaseManager.cpp; path = Modules/webdatabase/DatabaseManager.cpp; sourceTree = "<group>"; };
 		FE456F171677D74E005EDDF9 /* DatabaseManager.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = DatabaseManager.h; path = Modules/webdatabase/DatabaseManager.h; sourceTree = "<group>"; };
+		FE4AADEC16D2C37400026FFC /* AbstractSQLStatement.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = AbstractSQLStatement.h; path = Modules/webdatabase/AbstractSQLStatement.h; sourceTree = "<group>"; };
+		FE4AADED16D2C37400026FFC /* AbstractSQLStatementBackend.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = AbstractSQLStatementBackend.h; path = Modules/webdatabase/AbstractSQLStatementBackend.h; sourceTree = "<group>"; };
 		FE6F6AAD169E057500FC30A2 /* DatabaseBackendContext.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = DatabaseBackendContext.cpp; path = Modules/webdatabase/DatabaseBackendContext.cpp; sourceTree = "<group>"; };
 		FE6F6AAE169E057500FC30A2 /* DatabaseBackendContext.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; name = DatabaseBackendContext.h; path = Modules/webdatabase/DatabaseBackendContext.h; sourceTree = "<group>"; };
 		FE6FD4850F676E5700092873 /* Coordinates.h */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.c.h; path = Coordinates.h; sourceTree = "<group>"; };
@@ -18659,6 +18663,8 @@
 			isa = PBXGroup;
 			children = (
 				FE115FA9167988CD00249134 /* AbstractDatabaseServer.h */,
+				FE4AADEC16D2C37400026FFC /* AbstractSQLStatement.h */,
+				FE4AADED16D2C37400026FFC /* AbstractSQLStatementBackend.h */,
 				FE36FD1116C7826400F887C1 /* ChangeVersionData.h */,
 				97BC69D81505F076001B74AC /* ChangeVersionWrapper.cpp */,
 				97BC69D91505F076001B74AC /* ChangeVersionWrapper.h */,
@@ -23185,6 +23191,8 @@
 			buildActionMask = 2147483647;
 			files = (
 				FE115FAB167988CD00249134 /* AbstractDatabaseServer.h in Headers */,
+				FE4AADEE16D2C37400026FFC /* AbstractSQLStatement.h in Headers */,
+				FE4AADEF16D2C37400026FFC /* AbstractSQLStatementBackend.h in Headers */,
 				41E1B1D10FF5986900576B3B /* AbstractWorker.h in Headers */,
 				29A8122E0FBB9C1D00510293 /* AccessibilityARIAGridCell.h in Headers */,
 				29A812330FBB9C1D00510293 /* AccessibilityARIAGridRow.h in Headers */,
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebCore/Modules/webdatabase/SQLStatement.h	2013-02-18 22:11:47 UTC (rev 143263)
+++ trunk/Source/WebCore/Modules/webdatabase/SQLStatement.h	2013-02-18 22:31:54 UTC (rev 143264)
@@ -30,6 +30,7 @@
 
 #if ENABLE(SQL_DATABASE)
 
+#include "AbstractSQLStatement.h"
 #include "SQLCallbackWrapper.h"
 #include "SQLResultSet.h"
 #include "SQLValue.h"
@@ -39,32 +40,32 @@
 
 namespace WebCore {
 
+class AbstractSQLStatementBackend;
 class Database;
 class SQLError;
-class SQLStatementBackend;
 class SQLStatementCallback;
 class SQLStatementErrorCallback;
 class SQLTransaction;
 
-class SQLStatement {
+class SQLStatement : public AbstractSQLStatement {
 public:
     static PassOwnPtr<SQLStatement> create(Database*,
         PassRefPtr<SQLStatementCallback>, PassRefPtr<SQLStatementErrorCallback>);
 
     bool performCallback(SQLTransaction*);
 
-    void setBackend(SQLStatementBackend*);
+    virtual void setBackend(AbstractSQLStatementBackend*);
 
-    bool hasCallback();
-    bool hasErrorCallback();
+    virtual bool hasCallback();
+    virtual bool hasErrorCallback();
 
 private:
     SQLStatement(Database*, PassRefPtr<SQLStatementCallback>, PassRefPtr<SQLStatementErrorCallback>);
 
     // The SQLStatementBackend owns the SQLStatement. Hence, the backend is
     // guaranteed to be outlive the SQLStatement, and it is safe for us to refer
     // to the backend using a raw pointer here.
-    SQLStatementBackend* m_backend;
+    AbstractSQLStatementBackend* m_backend;
 
     SQLCallbackWrapper<SQLStatementCallback> m_statementCallbackWrapper;
     SQLCallbackWrapper<SQLStatementErrorCallback> m_statementErrorCallbackWrapper;
@@ -39,32 +40,32 @@
     SQLStatement(Database*, PassRefPtr<SQLStatementCallback>, PassRefPtr<SQLStatementErrorCallback>);
 
-    // The SQLStatementBackend owns the SQLStatement. Hence, the backend is
+    // The AbstractSQLStatementBackend owns the SQLStatement. Hence, the backend is
     // guaranteed to be outlive the SQLStatement, and it is safe for us to refer
     // to the backend using a raw pointer here.

Modified: trunk/Source/WebCore/Modules/webdatabase/SQLStatementBackend.cpp (143263 => 143264)

